@@ -4,6 +4,7 @@
 TimeStratPetersenDiagError_fit<- function( title="TSDPE", prefix="TSPDE-", 
                                  time, n1, m2, u2, sampfrac, jump.after=NULL, bad.m2=c(),
                                  logitP.cov=rep(1,length(n1)),
+                                 n.chains=3, n.iter=200000, n.burnin=100000, n.sims=2000,
                                  tauU.alpha=1, tauU.beta=.05, taueU.alpha=1, taueU.beta=.05, 
                                  mu_xiP=logit(sum(m2,na.rm=TRUE)/sum(n1,na.rm=TRUE)),
                                  tau_xiP=1/var(logit((m2+.5)/(n1+1)),na.rm=TRUE), 
@@ -269,7 +270,7 @@ if (debug)
             time=new.time, n1=new.n1, m2=new.m2, u2=new.u2,
             jump.after=jump.after-min(time)+1,
             logitP.cov=new.logitP.cov,
-            n.chains=3, n.iter=2000, n.burnin=300, n.sims=300, 
+            n.chains=3, n.iter=2000, n.burnin=300, n.sims=300,  # set to low values for debugging purposes only
             tauU.alpha=tauU.alpha, tauU.beta=tauU.beta, taueU.alpha=taueU.alpha, taueU.beta=taueU.beta,
             debug=debug, debug2=debug2, openbugs=openbugs, InitialSeed=InitialSeed ,
             OPENBUGS.directory=OPENBUGS.directory, WINBUGS.directory=WINBUGS.directory)
@@ -277,6 +278,7 @@ if (debug)
    {results <- TimeStratPetersenDiagError(title=title, prefix=prefix, 
             time=new.time, n1=new.n1, m2=new.m2, u2=new.u2, 
             jump.after=jump.after-min(time)+1, logitP.cov=new.logitP.cov,
+            n.chains=n.chains, n.iter=n.iter, n.burnin=n.burnin, n.sims=n.sims,
             tauU.alpha=tauU.alpha, tauU.beta=tauU.beta, taueU.alpha=taueU.alpha, taueU.beta=taueU.beta,
             debug=debug, debug2=debug2, openbugs=openbugs, InitialSeed=InitialSeed,
             OPENBUGS.directory=OPENBUGS.directory, WINBUGS.directory=WINBUGS.directory)
@@ -396,7 +398,7 @@ plot_logitP <- function(title, time, n1, m2, u2, logitP.cov, results){
       segments(time[1], intercept["mean"]+2*sigmaP["mean"], time[Nstrata], intercept["mean"]+2*sigmaP["mean"], lty=3)
    }
    if(ncol(logitP.cov)>1){  # if exactly 2 covariates, plot the second covarite over time as well
-      par(new=T)   # reuse the same plot
+      par(new=TRUE)   # reuse the same plot
       plot(time, logitP.cov[,2], type="l", lty=2, axes=FALSE, xlab="", ylab="")  # plot the covariate
    }
 
