@@ -1,10 +1,12 @@
+# 2010-03-03 CJS allowed some logitP[j] top be fixed at arbitrary values (on the logit scale)
+#                added definition of storage.class(logitP) to deal with no fixed values where the program bombed
 # 2009-12-07 CJS changed etaP to logitP
 # 2009-12-05 CJS added title to argument list
 # 2009-12-01 CJS added openbugs/winbugs directory to argument list
 
 TimeStratPetersenNonDiagError <- function(title, prefix, time, n1, m2, u2,
                      jump.after=NULL,
-                     logitP.cov,
+                     logitP.cov=rep(1,length(u2)), logitP.fixed=rep(NA,length(u2)),
                      n.chains=3, n.iter=200000, n.burnin=100000, n.sims=2000, 
                      tauU.alpha=1, tauU.beta=.05, taueU.alpha=1, taueU.beta=.05,
                      mu_xiP=-2, tau_xiP=.6666, 
@@ -41,6 +43,10 @@ TimeStratPetersenNonDiagError <- function(title, prefix, time, n1, m2, u2,
 #      jump.after - points after which the spline is allowed to jump. Specify as a list of integers in the 
 #              range of 1:Nstrata. If jump.after[i]=k, then the spline is split between strata k and k+1
 #      logitP.cov - covariates for logit(P)=X beta.logitP.cov
+#                 - specify anything you want for fixed logitP's as the covariate values are simply ignored. 
+#                 - recommend that you specify 1 for the intercept and 0's for everything else
+#      logitP.fixed- values for logitP that are fixed in advance. Use NA if corresponding value is not fixed, 
+#                    otherwise specify the logitP value.
 
 
 #  This routine makes a call to WinBugs to fit the model and then gets back the 
@@ -71,6 +77,9 @@ model TimeStratPetersenNonDiagError{
 #                   Entries in the last column are the number of fish NEVER recaptured from those
 #                   released
 #      u2         - number of unmarked fish captured (To be expanded to population).
+#      logitP     - the recapture rates. Use NA if these are modelled, otherwise specify the logit(fixed value, e.g. -10 for 0).
+#      Nfree.logitP - number of free logitP parameters
+#      free.logitP.index - vector of length(Nfree.logitP) for the free logitP parameters
 #      logitP.cov - covariates for logitP
 #      NlogitP.cov  - number of logitP covariates
 #      SplineDesign- spline design matrix of size [Nstrata, maxelement of n.b.notflat]
@@ -110,8 +119,10 @@ model TimeStratPetersenNonDiagError{
         logUne[i] <- inprod(SplineDesign[i,1:n.bU],bU[1:n.bU])  # spline design matrix * spline coeff 
         etaU[i] ~ dnorm(logUne[i], taueU)              # add random error
         eU[i] <- etaU[i] - logUne[i]
-        mu.logitP[i] <- inprod(logitP.cov[i,1:NlogitP.cov], beta.logitP[1:NlogitP.cov]) 
-        logitP[i] ~ dnorm(mu.logitP[i],tauP)
+   }
+   for(i in 1:Nfree.logitP){   # model the free capture rates using covariates
+        mu.logitP[free.logitP.index[i]] <- inprod(logitP.cov[free.logitP.index[i],1:NlogitP.cov], beta.logitP[1:NlogitP.cov]) 
+        logitP[free.logitP.index[i]] ~ dnorm(mu.logitP[free.logitP.index[i]],tauP)
    }
 
 
@@ -185,7 +196,7 @@ model TimeStratPetersenNonDiagError{
    }
    ## Capture probabilities and run size
    for(j in 1:Nstrata.cap){
-      logit(p[j]) <- logitP[j]       # convert from logit scale
+      logit(p[j]) <- max(-10,min(10,logitP[j]))    # convert from logit scale; use limits to avoid over/underflow
       U[j]   <- round(exp(etaU[j]))       # convert from log scale
       u2[j] ~ dbin(p[j],U[j])      # capture of newly unmarked fish
    }
@@ -230,7 +241,7 @@ for (i in 1:(length(ext.jump)-1)){
   all.knots <- c(all.knots, knots)
   # compute the design matrix for this set of strata
   z <- bs((1:nstrata.in.set)/(nstrata.in.set+1), knots=knots, degree=SplineDegree, 
-             intercept=T, Boundary.knots=c(0,1))
+             intercept=TRUE, Boundary.knots=c(0,1))
   # first two elements of b coeffients have a flat prior
   b.flat <- c(b.flat, ncol(SplineDesign)+(1:2))
   b.notflat <- c(b.notflat, ncol(SplineDesign)+3:(ncol(z)))
@@ -248,7 +259,16 @@ n.bU <- n.b.flat + n.b.notflat
 logitP.cov <- as.matrix(logitP.cov)
 NlogitP.cov <- ncol(as.matrix(logitP.cov))
 
-datalist <- list("Nstrata.rel", "Nstrata.cap", "n1", "m2", "u2", "logitP.cov", "NlogitP.cov",
+# get the logitP's ready to allow for fixed values
+logitP <- as.numeric(logitP.fixed)
+storage.mode(logitP) <- "double" # if there are no fixed logits, the default class will be logical which bombs
+free.logitP.index <- (1:Nstrata.cap)[ is.na(logitP.fixed)]  # free values are those where NA is specifed
+Nfree.logitP <- length(free.logitP.index)
+
+
+datalist <- list("Nstrata.rel", "Nstrata.cap", "n1", "m2", "u2", 
+                 "logitP", "Nfree.logitP", "free.logitP.index",   # those indices that are fixed and free to vary
+                 "logitP.cov", "NlogitP.cov",
                  "SplineDesign",
                  "b.flat", "n.b.flat", "b.notflat", "n.b.notflat", "n.bU",
                  "tauU.alpha", "tauU.beta", "taueU.alpha", "taueU.beta",
@@ -294,8 +314,9 @@ if( any(is.na(u2))) {parameters <- c(parameters,"u2")}
 init.vals <- function(){
    init.logitP <- c(logit((apply(m2[,1:Nstrata.cap],1,sum)+1)/(n1+1)),rep(mu_xiP,Nstrata.cap-Nstrata.rel))         # initial capture rates based on observed recaptures
    init.logitP[is.na(init.logitP)] <- -2         # those cases where initial probability is unknown
+   init.logitP[!is.na(logitP.fixed)]<- NA        # no need to initialize the fixed values
    init.beta.logitP <- as.vector(lm( init.logitP ~ logitP.cov-1)$coefficients)
-   init.beta.logitP[init.beta.logitP=NA] <- 0 
+   init.beta.logitP[is.na(init.beta.logitP)] <- 0 
    init.beta.logitP <- c(init.beta.logitP, 0)   # add one extra element so that single beta is still written as a 
                                              # vector in the init files etc.
    init.tauP <- 1/var(init.logitP, na.rm=TRUE)     # 1/variance of logit(p)'s (ignoring the covariates for now)
@@ -308,7 +329,7 @@ init.vals <- function(){
    sigmaU <- sd( init.bU[b.notflat]-2*init.bU[b.notflat-1]+init.bU[b.notflat-2], na.rm=TRUE)
    init.tauU <- 1/sigmaU^2
 
-   # variance of error in the U' over and above the spline fit
+   # variance of error in the U over and above the spline fit
    sigmaeU <- sd(init.eU, na.rm=TRUE)
    init.taueU <- 1/sigmaeU^2
 
@@ -334,6 +355,7 @@ init.vals <- function(){
 
 # set up for the call to WinBugs or OpenBugs
 
+working.directory <- getwd()          # store all data and init files in the current directory
 if(openbugs){
    cat("\n\n*** Start of call to OpenBugs \n")
    bugs.directory = OPENBUGS.directory 
@@ -346,7 +368,6 @@ if(openbugs){
    over.relax <- FALSE
    parameters.to.save <- c(parameters, "deviance")  # always get the deviance
    parametersToSave <- parameters.to.save
-   working.directory = getwd()          # store all data and init files in the current directory
 
    cat("OpenBugs files created in:", working.directory, "\n")
    BRugs::modelCheck(modelFile)    # check the model
@@ -416,7 +437,7 @@ if(openbugs){
    cat("Final dimension of saved simulation output is ", dim(results$sims.array), "\n")
 
    # save the information to the coda files
-   BRugs::samplesCoda("*", stem=paste(working.directory,"/",sep=""))  # write out code files
+   BRugs::samplesCoda("*", stem=paste(working.directory,"/",sep=""))  # write out coda files
    cat("Coda file created \n")
 
    cat("\n\n*** Finished OpenBugs ***\n\n")
@@ -433,6 +454,7 @@ if(openbugs){
       n.burnin=n.burnin,
       n.sims=n.sims,      # (approx) number of final simulations to save
       bugs.directory=bugs.directory,
+      working.directory=working.directory,
       debug=debug     )
    results
    } # end of else clause
